@@ -1,8 +1,8 @@
 # Module: FeatureEngineering
 # Author: Adrian Antico <adrianantico@gmail.com>
 # License: MIT
-# Release: retrofit 0.0.9
-# Last modified : 2021-09-02
+# Release: retrofit 0.1.0
+# Last modified : 2021-09-03
 
 def FE0_AutoLags(data = None, ArgsList=None, LagColumnNames = None, DateColumnName = None, ByVariables = None, LagPeriods = 1, ImputeValue = -1, Sort = True, Processing='datatable', InputFrame='datatable', OutputFrame='datatable'):
     """
@@ -209,7 +209,7 @@ def FE0_AutoLags(data = None, ArgsList=None, LagColumnNames = None, DateColumnNa
     return dict(data = data, ArgsList = ArgsList)
 
 
-def FE0_AutoRollStats(data = None, ArgsList=None, RollColumnNames = None, DateColumnName = None, ByVariables = None, MovingAvg_Periods = 2, MovingSD_Periods = None, MovingMin_Periods = None, MovingMax_Periods = None, ImputeValue = -1, Sort = True, Processing='datatable', InputFrame='datatable', OutputFrame='datatable'):
+def FE0_AutoRollStats(data = None, ArgsList=None, RollColumnNames = None, DateColumnName = None, ByVariables = None, MovingAvg_Periods = None, MovingSD_Periods = None, MovingMin_Periods = None, MovingMax_Periods = None, ImputeValue = -1, Sort = True, Processing='datatable', InputFrame='datatable', OutputFrame='datatable'):
     """
     # Goal:
     Automatically generate rolling averages, standard deviations, mins and maxes for multiple periods for multiple variables and by variables
@@ -1030,8 +1030,6 @@ def FE2_AutoDataParition(data=None, ArgsList=None, DateColumnName=None, Partitio
     from retrofit import utils as u
     
     # random
-    data = pl.read_csv("C:/Users/Bizon/Documents/GitHub/RemixAutoML/tests/QA_DataSets/ThreeGroup-FC-Walmart-XREG3.csv")
-    data = pl.read_csv('https://www.dropbox.com/s/2str3ek4f4cheqi/walmart_train.csv?dl=1')
     data = pl.read_csv("C:/Users/Bizon/Documents/GitHub/BenchmarkData.csv")
     t_start = timeit.default_timer()
     DataSets = fe.FE2_AutoDataParition(data=data, ArgsList=None, DateColumnName='CalendarDateColumn', PartitionType='random', Ratios=[0.70,0.20,0.10], Sort=False, ByVariables=None, Processing='polars', InputFrame='polars', OutputFrame='polars')
@@ -1104,7 +1102,6 @@ def FE2_AutoDataParition(data=None, ArgsList=None, DateColumnName=None, Partitio
     # Import polars methods
     if Processing.lower() == 'polars' or OutputFrame.lower() == 'polars' or InputFrame.lower() == 'polars':
       import polars as pl
-      from polars.lazy import col
 
     # Convert to datatable
     if InputFrame.lower() == 'pandas' and Processing.lower() == 'datatable':
@@ -1114,59 +1111,41 @@ def FE2_AutoDataParition(data=None, ArgsList=None, DateColumnName=None, Partitio
 
     # Accumulate Ratios
     Ratios = u.cumsum(Ratios)
-    
+
     # datatable
     if Processing.lower() == 'datatable':
-      
+
       # Random partitioning
       if PartitionType.lower() == 'random':
-        
+
         # Add random number column
         data = data[:, f[:].extend({"ID": np.random.uniform(0,1, size = data.shape[0])})]
-        
-        # Sort data
-        data = data[:, :, sort(f['ID'])]
-        
-        # TrainData
-        TrainData = data[f['ID'] <= Ratios[0], ...]
-        del TrainData['ID']
-        
-        # ValidationData
-        ValidationData = data[(f['ID'] <= Ratios[1]) & (f['ID'] > Ratios[0]), ...]
-        del ValidationData['ID']
-        
-        # TestData
-        if len(Ratios) == 3:
-          TestData = data[f['ID'] > Ratios[1], ...]
-          del TestData['ID']
-        else:
-          TestData = None
 
       # Time base partitioning
       if PartitionType.lower() == 'time':
-        
-        # Number of rows
-        NumRows = data.nrows
-        
+
         # Sort data
         if Sort == True:
           data = data[:, :, sort(f[DateColumnName], reverse = False)]
+
+      # Number of rows
+      NumRows = data.nrows
+          
+      # Grab row number boundaries
+      TrainRowsMax = NumRows * Ratios[0]
+      ValidRowsMax = NumRows * Ratios[1]
         
-        # Grab row number boundaries
-        TrainRowsMax = NumRows * Ratios[0]
-        ValidRowsMax = NumRows * Ratios[1]
+      # TrainData
+      TrainData = data[:int(TrainRowsMax), ...]
         
-        # TrainData
-        TrainData = data[range(int(TrainRowsMax)), ...]
+      # ValidationData
+      ValidationData = data[int(TrainRowsMax+1):int(ValidRowsMax), ...]
         
-        # ValidationData
-        ValidationData = data[range(int(TrainRowsMax+1), int(ValidRowsMax)), ...]
-        
-        # TestData
-        if len(Ratios) == 3:
-          TestData = data[range(int(ValidRowsMax), NumRows), ...]
-        else:
-          TestData = None
+      # TestData
+      if len(Ratios) == 3:
+        TestData = data[int(ValidRowsMax):, ...]
+      else:
+        TestData = None
 
     # polars
     if Processing.lower() == 'polars':
@@ -1174,60 +1153,36 @@ def FE2_AutoDataParition(data=None, ArgsList=None, DateColumnName=None, Partitio
       # Random partitioning
       if PartitionType.lower() == 'random':
         
-        # Add random number column
+        # Prepare data
         data['ID'] = np.random.uniform(0,1, size = data.shape[0])
-        
-        # Sort data
         data = data.sort('ID')
+        data.drop_in_place('ID')
         
-        # TrainData
-        TrainData = data[data['ID'] <= Ratios[0]]
-        TrainData.drop_in_place('ID')
-        
-        # ValidationData
-        ValidationData = data[(data['ID'] <= Ratios[1]) & (data['ID'] > Ratios[0])]
-        ValidationData.drop_in_place('ID')
-        
-        # TestData
-        if len(Ratios) == 3:
-          TestData = data[data['ID'] > Ratios[1]]
-          TestData.drop_in_place('ID')
-        else:
-          TestData = None
-
       # Time base partitioning
       if PartitionType.lower() == "time":
         
-        # Number of rows
-        NumRows = data.shape[0]
-        
-        # Sort data
+        # Prepare data
         if Sort == True:
           data.sort(DateColumnName, reverse = False, in_place = True)
+      
+      # Number of rows
+      NumRows = data.shape[0]
+          
+      # Grab row number boundaries
+      TrainRowsMax = NumRows * Ratios[0]
+      ValidRowsMax = NumRows * Ratios[1]
+        
+      # TrainData
+      TrainData = data[:int(TrainRowsMax)]
 
-        # Add an index to filter by
-        data = (data.with_column(
-          pl.arange(0,data.shape[0]).alias("index")
-        ))
-
-        # Grab row number boundaries
-        TrainRowsMax = NumRows * Ratios[0]
-        ValidRowsMax = NumRows * Ratios[1]
+      # ValidationData
+      ValidationData = data[int(TrainRowsMax + 1):int(ValidRowsMax)]
         
-        # TrainData
-        TrainData = data[data['index'] <= int(TrainRowsMax)]
-        TrainData.drop_in_place('index')
-        
-        # ValidationData
-        ValidationData = data[(data['index'] > int(TrainRowsMax + 1)) & (data['index'] <= int(ValidRowsMax))]
-        ValidationData.drop_in_place('index')
-        
-        # TestData
-        if len(Ratios) == 3:
-          TestData = data[data['index'] > int(ValidRowsMax + 1)]
-          TestData.drop_in_place('index')
-        else:
-          TestData = None
+      # TestData
+      if len(Ratios) == 3:
+        TestData = data[int(ValidRowsMax + 1):]
+      else:
+        TestData = None
     
     # Convert Frame
     if OutputFrame.lower() == 'pandas' and (Processing.lower() == 'datatable' or Processing.lower() == 'polars'):
