@@ -1,8 +1,8 @@
 # Module: MachineLearning
 # Author: Adrian Antico <adrianantico@gmail.com>
 # License: MIT
-# Release: retrofit 0.0.9
-# Last modified : 2021-09-02
+# Release: retrofit 0.1.0
+# Last modified : 2021-09-03
 
 def ML0_GetModelData(TrainData=None, ValidationData=None, TestData=None, ArgsList=None, TargetColumnName=None, NumericColumnNames=None, CategoricalColumnNames=None, TextColumnNames=None, WeightColumnName=None, Threads=-1, Processing='catboost', InputFrame='datatable'):
     """
@@ -10,7 +10,7 @@ def ML0_GetModelData(TrainData=None, ValidationData=None, TestData=None, ArgsLis
     Create modeling objects for specific algorithms. E.g. create train, valid, and test objects for catboost
     
     # Output
-    Return frames for catboost, xgboost, lightgbm, etc.
+    Return frames for catboost, xgboost, and lightgbm, currently.
     
     # Parameters
     TrainData:              Source data. Either a datatable frame, polars frame, or pandas frame. The function will run either datatable code or polars code. If your input frame is pandas
@@ -23,7 +23,7 @@ def ML0_GetModelData(TrainData=None, ValidationData=None, TestData=None, ArgsLis
     TextColumnNames:        List of integers for the lookback lengths
     WeightColumnName:       Value to fill the NA's for beginning of series
     Threads:                Number of threads to utilize if available for the algorithm
-    Processing:             'datatable' or 'polars'. Choose the package you want to do your processing
+    Processing:             'catboost', 'xgboost', or 'lightgbm'
     InputFrame:             'datatable', 'polars', or 'pandas' If you input Frame is 'pandas', it will be converted to a datatable Frame for generating the new columns
 
     # ML0_GetModelData Example:
@@ -148,13 +148,6 @@ def ML0_GetModelData(TrainData=None, ValidationData=None, TestData=None, ArgsLis
       
       # Imports
       from catboost import Pool
-      
-      # label
-      TrainLabel = TrainData[TargetColumnName].to_numpy()
-      if not ValidationData is None:
-        ValidationLabel = ValidationData[TargetColumnName].to_numpy()
-      if not TestData is None:
-        TestLabel = TestData[TargetColumnName].to_numpy()
 
       # data (numeric features)
       if not NumericColumnNames is None:
@@ -218,3 +211,133 @@ def ML0_GetModelData(TrainData=None, ValidationData=None, TestData=None, ArgsLis
     
       # Return catboost
       return dict(train_data=train_data, validation_data=validation_data, test_data=test_data, ArgsList=ArgsList)
+
+    # XGBoost
+    if Processing.lower() == 'xgboost':
+      
+      # Imports
+      import xgboost as xgb
+
+      # data (numeric features)
+      if not NumericColumnNames is None:
+        SD = copy.copy(NumericColumnNames)
+      else:
+        SD = []
+      # if not CategoricalColumnNames is None:
+      #   for nam in CategoricalColumnNames:
+      #     SD.append(nam)
+      # if not TextColumnNames is None:
+      #   for nam in TextColumnNames:
+      #     SD.append(nam)
+      if not WeightColumnName is None:
+        trainweightdata = TrainData['WeightColumnName'].to_pandas()
+        if not ValidationData is None:
+          validationweightdata = ValidationData['WeightColumnName'].to_pandas()
+        if not TestData is None:
+          testweightdata = TestData['WeightColumnName'].to_pandas()
+      else:
+        trainweightdata = None
+        validationweightdata = None
+        testweightdata = None
+        
+      # data
+      train = TrainData[:, SD].to_pandas()
+      if not ValidationData is None:
+        validation = ValidationData[:, SD].to_pandas()
+      if not TestData is None:
+        test = TestData[:, SD].to_pandas()
+
+      # label
+      trainlabel = TrainData[:, TargetColumnName].to_pandas()
+      if not ValidationData is None:
+        validationlabel = ValidationData[:, TargetColumnName].to_pandas()
+      if not TestData is None:
+        testlabel = TestData[:, TargetColumnName].to_pandas()
+
+      # TrainData
+      if trainweightdata is None:
+        train_data = xgb.DMatrix(data = train, label = trainlabel)
+      else:
+        train_data = xgb.DMatrix(data = train, label = trainlabel, weight = trainweightdata)
+      
+      # ValidationData
+      if not ValidationData is None:
+        if validationweightdata is None:
+          validation_data = xgb.DMatrix(data = validation, label = validationlabel)
+        else:
+          validation_data = xgb.DMatrix(data = validation, label = validationlabel, weight = validationweightdata)
+        
+      # TestData
+      if not TestData is None:
+        if testweightdata is None:
+          test_data = xgb.DMatrix(data = test, label = testlabel)
+        else:
+          test_data = xgb.DMatrix(data = test, label = testlabel, weights = testweightdata)
+    
+      # Return catboost
+      return dict(train_data=train_data, validation_data=validation_data, test_data=test_data, ArgsList=ArgsList)
+    
+    # LightGBM
+    if Processing.lower() == 'lightgbm':
+      
+      # Imports
+      import lightgbm as lgbm
+
+      # data (numeric features)
+      if not NumericColumnNames is None:
+        SD = copy.copy(NumericColumnNames)
+      else:
+        SD = []
+      if not CategoricalColumnNames is None:
+        for nam in CategoricalColumnNames:
+          SD.append(nam)
+      if not TextColumnNames is None:
+        for nam in TextColumnNames:
+          SD.append(nam)
+      if not WeightColumnName is None:
+        trainweightdata = TrainData['WeightColumnName']
+        if not ValidationData is None:
+          validationweightdata = ValidationData['WeightColumnName']
+        if not TestData is None:
+          testweightdata = TestData['WeightColumnName']
+      else:
+        trainweightdata = None
+        validationweightdata = None
+        testweightdata = None
+        
+      # data
+      train = TrainData[:, SD]
+      if not ValidationData is None:
+        validation = ValidationData[:, SD]
+      if not TestData is None:
+        test = TestData[:, SD]
+
+      # label
+      trainlabel = TrainData[:, TargetColumnName]
+      if not ValidationData is None:
+        validationlabel = ValidationData[:, TargetColumnName]
+      if not TestData is None:
+        testlabel = TestData[:, TargetColumnName]
+
+      # TrainData
+      if trainweightdata is None:
+        train_data = lgbm.Dataset(data = train, label = trainlabel)
+      else:
+        train_data = lgbm.Dataset(data = train, label = trainlabel, weight = trainweightdata)
+      
+      # ValidationData
+      if not ValidationData is None:
+        if validationweightdata is None:
+          validation_data = lgbm.Dataset(data = validation, label = validationlabel)
+        else:
+          validation_data = lgbm.Dataset(data = validation, label = validationlabel, weight = validationweightdata)
+        
+      # TestData
+      if not TestData is None:
+        if testweightdata is None:
+          test_data = lgbm.Dataset(data = test, label = testlabel)
+        else:
+          test_data = lgbm.Dataset(data = test, label = testlabel, weights = testweightdata)
+    
+      # Return catboost
+      return dict(train_data=train_data, validation_data=validation_data, test_data=test_data, ArgsList=ArgsList)
